==> mobGameSDK-5.0.2-sources.jar: com/game/sdk/comon/game/LifeCycleActivity.java <==
package com.game.sdk.comon.game;

import android.app.Activity;
import android.content.Intent;
import android.content.res.Configuration;
import android.support.annotation.Nullable;
import android.text.TextUtils;

import com.appsflyer.AppsFlyerLib;
import com.game.sdk.comon.api.ErrorCode;
import com.game.sdk.comon.config.GameConfigs;
import com.game.sdk.comon.constants.Constants;
import com.game.sdk.comon.object.UserObj;
import com.game.sdk.comon.object.err.SdkConfigErrObj;
import com.game.sdk.comon.object.err.UserErrObj;
import com.game.sdk.comon.object.response.SdkConfigResponseObj;
import com.game.sdk.comon.object.response.UserResponseObj;
import com.game.sdk.comon.presenter.BaseView;
import com.game.sdk.comon.sharePref.PrefManager;
import com.game.sdk.comon.utils.DialogUtils;
import com.game.sdk.comon.utils.ToastUtils;
import com.game.sdk.comon.utils.Utils;
import com.game.sdk.ui.login.ILoginPresenter;
import com.game.sdk.ui.login.LoginPresenterImpl;
import com.mobgame.MobGameSDK;
import com.mobgame.R;


public class LifeCycleActivity implements BaseView {
    public static LifeCycleActivity mobGameActivity;
    Activity activity;
    boolean isFirstLauch;
    ILoginPresenter loginPresenter;

    public static LifeCycleActivity getInstance(Activity activity) {
        if (mobGameActivity == null)
            mobGameActivity = new LifeCycleActivity(activity);
        return mobGameActivity;
    }

    public LifeCycleActivity(Activity activity) {
        isFirstLauch = true;
        this.activity = activity;
        loginPresenter = new LoginPresenterImpl(this);
    }


    public void onCreate() {
        if (GameConfigs.getInstance().getUser() != null && GameConfigs.getInstance().isLogin()) {
            loginPresenter.getSdkConfig();
        } else {
            isFirstLauch = false;
        }
    }

    public void onStart() {
    }


    public void onResume() {
        if (isFirstLauch) {
            return;
        }
        if (!TextUtils.isEmpty(PrefManager.getAccessToken(activity))) {
            loginPresenter = new LoginPresenterImpl(this);
            loginPresenter.getUser();
        }
    }

    public void onPause() {
    }

    public void onStop() {
    }

    public void onDestroy() {
    }

    public void onWindowFocusChanged(boolean hasFocus) {
    }

    public void onConfigurationChanged(Configuration newConfig) {
    }

    public void onLowMemory() {
    }

    public void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
    }


    @Override
    public void showProgress(String mess) {
        Utils.showLoading(activity,true);
    }

    @Override
    public void hideProgress() {
        Utils.showLoading(activity,false);
    }

    @Override
    public void success(Object x) {
        if (x instanceof UserResponseObj) {
            UserObj obj = ((UserResponseObj) x).getData();
            GameConfigs.getInstance().setUser(obj);
        } else if (x instanceof SdkConfigResponseObj) {
            SdkConfigResponseObj obj = (SdkConfigResponseObj) x;
            GameConfigs.getInstance().setSdkConfig(obj.getData());
            if (obj != null && obj.getData() != null && obj.getData().getMaintenance() != null && !TextUtils.isEmpty(obj.getData().getMaintenance().getUrl())) {
                MobGameSDK.getInstance().getQueuePopups().add(MobGameSDK.POPUP_MAINTAIN);
                MobGameSDK.getInstance().showPopup();
                return;
            }
            try {
                AppsFlyerLib.getInstance().setCustomerUserId(GameConfigs.getInstance().getUser().getId() + "");
            } catch (Exception e) {
                e.printStackTrace();
            }
            GameSdk.getInstance().onLoginSuccess(activity, "login");
            isFirstLauch = false;
        }
    }

    @Override
    public void error(Object o) {
        if (o instanceof UserErrObj) {
            UserErrObj obj = (UserErrObj) o;
            if (obj.getStatus() == Constants.USER_ERR_CODE.INVALID_TOKEN) {
                DialogUtils.showExpireDialog(activity);
            } else {
                if (obj.getStatus() == ErrorCode.NO_INTERNET)
                    ToastUtils.showErrToast(activity, activity.getString(R.string.error_network));
                DialogUtils.showRetryDialog(activity, obj.getMessage(), new DialogUtils.Listener() {
                    @Override
                    public void onRetry() {
                        onResume();
                    }
                });
            }
        } else if (o instanceof SdkConfigErrObj) {
            SdkConfigErrObj obj = (SdkConfigErrObj) o;
            if (obj.getStatus() == Constants.USER_ERR_CODE.INVALID_TOKEN) {
                DialogUtils.showExpireDialog(activity);
            } else {
                if (obj.getStatus() == ErrorCode.NO_INTERNET) {
                    DialogUtils.showRetryDialog(activity, activity.getString(R.string.error_network), new DialogUtils.Listener() {
                        @Override
                        public void onRetry() {
                            ILoginPresenter loginPresenter = new LoginPresenterImpl(LifeCycleActivity.this);
                            loginPresenter.getSdkConfig();
                        }
                    });
                } else {
                    DialogUtils.showRetryDialogWithLogOut(activity, obj.getMessage(), new DialogUtils.Listener() {
                        @Override
                        public void onRetry() {
                            ILoginPresenter loginPresenter = new LoginPresenterImpl(LifeCycleActivity.this);
                            loginPresenter.getSdkConfig();
                        }
                    });
                }
            }
        }
    }
}

==> mobGameSDK-5.0.5-sources.jar: com/game/sdk/comon/game/LifeCycleActivity.java <==
package com.game.sdk.comon.game;

import android.app.Activity;
import android.content.Intent;
import android.content.res.Configuration;
import android.support.annotation.Nullable;
import android.text.TextUtils;

import com.appsflyer.AppsFlyerLib;
import com.game.sdk.comon.api.ErrorCode;
import com.game.sdk.comon.config.GameConfigs;
import com.game.sdk.comon.constants.Constants;
import com.game.sdk.comon.object.UserObj;
import com.game.sdk.comon.object.err.SdkConfigErrObj;
import com.game.sdk.comon.object.err.UserErrObj;
import com.game.sdk.comon.object.response.SdkConfigResponseObj;
import com.game.sdk.comon.object.response.UserResponseObj;
import com.game.sdk.comon.presenter.BaseView;
import com.game.sdk.comon.sharePref.PrefManager;
import com.game.sdk.comon.utils.DialogUtils;
import com.game.sdk.comon.utils.LogUtils;
import com.game.sdk.comon.utils.ToastUtils;
import com.game.sdk.comon.utils.Utils;
import com.game.sdk.ui.login.ILoginPresenter;
import com.game.sdk.ui.login.LoginPresenterImpl;
import com.mobgame.MobGameSDK;
import com.mobgame.R;


public class LifeCycleActivity implements BaseView {
    public static LifeCycleActivity mobGameActivity;
    Activity activity;
    boolean isFirstLauch;
    ILoginPresenter loginPresenter;

    public static LifeCycleActivity getInstance(Activity activity) {
        if (mobGameActivity == null)
            mobGameActivity = new LifeCycleActivity(activity);
        return mobGameActivity;
    }

    public LifeCycleActivity(Activity activity) {
        isFirstLauch = true;
        this.activity = activity;
        loginPresenter = new LoginPresenterImpl(this);
    }


    public void onCreate() {
        if (GameConfigs.getInstance().getUser() != null && GameConfigs.getInstance().isLogin()) {
            loginPresenter.getUser();
        } else {
            isFirstLauch = false;
        }
    }

    public void onStart() {
    }


    public void onResume() {
        if (isFirstLauch) {
            return;
        }
        if (!TextUtils.isEmpty(PrefManager.getAccessToken(activity))) {
            loginPresenter = new LoginPresenterImpl(this);
            loginPresenter.getUser();
        }
    }

    public void onPause() {
    }

    public void onStop() {
    }

    public void onDestroy() {
    }

    public void onWindowFocusChanged(boolean hasFocus) {
    }

    public void onConfigurationChanged(Configuration newConfig) {
    }

    public void onLowMemory() {
    }

    public void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
    }


    @Override
    public void showProgress(String mess) {
        Utils.showLoading(activity, true);
    }

    @Override
    public void hideProgress() {
        Utils.showLoading(activity, false);
    }

    @Override
    public void success(Object x) {
        if (x instanceof UserResponseObj) {
            UserObj obj = ((UserResponseObj) x).getData();
            GameConfigs.getInstance().setUser(obj);
            if (isFirstLauch)
                loginPresenter.getSdkConfig();
            LogUtils.d("LifeCycleActivity", "User valid");
        } else if (x instanceof SdkConfigResponseObj) {
            try {
                isFirstLauch = false;
                SdkConfigResponseObj obj = (SdkConfigResponseObj) x;
                GameConfigs.getInstance().setSdkConfig(obj.getData());
                if (obj != null && obj.getData() != null && obj.getData().getMaintenance() != null && !TextUtils.isEmpty(obj.getData().getMaintenance().getUrl())) {
                    MobGameSDK.getInstance().getQueuePopups().add(MobGameSDK.POPUP_MAINTAIN);
                    MobGameSDK.getInstance().showPopup();
                    return;
                }
                AppsFlyerLib.getInstance().setCustomerUserId(GameConfigs.getInstance().getUser().getId() + "");
                GameSdk.getInstance().onLoginSuccess(activity, "login");
                LogUtils.d("LifeCycleActivity", "get game info success");
            } catch (Exception e) {
                LogUtils.d("LifeCycleActivity", e.getMessage());
            }
        }
    }

    @Override
    public void error(Object o) {
        if (o instanceof UserErrObj) {
            UserErrObj obj = (UserErrObj) o;
            if (obj.getStatus() == Constants.USER_ERR_CODE.INVALID_TOKEN) {
                DialogUtils.showExpireDialog(activity);
            } else {
                if (obj.getStatus() == ErrorCode.NO_INTERNET)
                    ToastUtils.showErrToast(activity, activity.getString(R.string.error_network));
                DialogUtils.showRetryDialog(activity, obj.getMessage(), new DialogUtils.Listener() {
                    @Override
                    public void onRetry() {
                        onResume();
                    }
                });
            }
        } else if (o instanceof SdkConfigErrObj) {
            SdkConfigErrObj obj = (SdkConfigErrObj) o;
            if (obj.getStatus() == Constants.USER_ERR_CODE.INVALID_TOKEN) {
                DialogUtils.showExpireDialog(activity);
            } else {
                if (obj.getStatus() == ErrorCode.NO_INTERNET) {
                    DialogUtils.showRetryDialog(activity, activity.getString(R.string.error_network), new DialogUtils.Listener() {
                        @Override
                        public void onRetry() {
                            ILoginPresenter loginPresenter = new LoginPresenterImpl(LifeCycleActivity.this);
                            loginPresenter.getSdkConfig();
                        }
                    });
                } else {
                    DialogUtils.showRetryDialogWithLogOut(activity, obj.getMessage(), new DialogUtils.Listener() {
                        @Override
                        public void onRetry() {
                            ILoginPresenter loginPresenter = new LoginPresenterImpl(LifeCycleActivity.this);
                            loginPresenter.getSdkConfig();
                        }
                    });
                }
            }
        }
    }
}
